# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202408 import RentcastMarketStatistics200ResponseRentalDataHistory202408

class TestRentcastMarketStatistics200ResponseRentalDataHistory202408(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202408 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202408:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202408
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202408`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202408()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202408(
                var_date = '2024-08-01T00:00:00.000Z',
                average_rent = 1496,
                median_rent = 1495,
                min_rent = 750,
                max_rent = 2800,
                average_rent_per_square_foot = 1.33,
                median_rent_per_square_foot = 1.27,
                min_rent_per_square_foot = 0.86,
                max_rent_per_square_foot = 2.52,
                average_square_footage = 1171,
                median_square_footage = 1100,
                min_square_footage = 650,
                max_square_footage = 2100,
                average_days_on_market = 66.49,
                median_days_on_market = 16,
                min_days_on_market = 1,
                max_days_on_market = 365,
                new_listings = 39,
                total_listings = 96,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_rental_data_history_2024_08_data_by_property_type_inner.market_statistics_200_response_rentalData_history_2024_08_dataByPropertyType_inner(
                        property_type = 'Apartment', 
                        average_rent = 1118, 
                        median_rent = 1050, 
                        min_rent = 750, 
                        max_rent = 1975, 
                        average_rent_per_square_foot = 1.24, 
                        median_rent_per_square_foot = 1.07, 
                        min_rent_per_square_foot = 0.98, 
                        max_rent_per_square_foot = 2.16, 
                        average_square_footage = 922, 
                        median_square_footage = 950, 
                        min_square_footage = 650, 
                        max_square_footage = 1560, 
                        average_days_on_market = 63.82, 
                        median_days_on_market = 17, 
                        min_days_on_market = 1, 
                        max_days_on_market = 365, 
                        new_listings = 8, 
                        total_listings = 23, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_rental_data_history_2024_08_data_by_bedrooms_inner.market_statistics_200_response_rentalData_history_2024_08_dataByBedrooms_inner(
                        bedrooms = 1, 
                        average_rent = 953, 
                        median_rent = 825, 
                        min_rent = 750, 
                        max_rent = 1610, 
                        average_rent_per_square_foot = 1.41, 
                        median_rent_per_square_foot = 1.3, 
                        min_rent_per_square_foot = 1.06, 
                        max_rent_per_square_foot = 2.16, 
                        average_square_footage = 732, 
                        median_square_footage = 675, 
                        min_square_footage = 650, 
                        max_square_footage = 950, 
                        average_days_on_market = 33.44, 
                        median_days_on_market = 17, 
                        min_days_on_market = 1, 
                        max_days_on_market = 124, 
                        new_listings = 3, 
                        total_listings = 10, )
                    ]
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202408(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202408(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202408"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_value_estimate200_response import RentcastValueEstimate200Response

class TestRentcastValueEstimate200Response(unittest.TestCase):
    """RentcastValueEstimate200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastValueEstimate200Response:
        """Test RentcastValueEstimate200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastValueEstimate200Response`
        """
        model = RentcastValueEstimate200Response()
        if include_optional:
            return RentcastValueEstimate200Response(
                price = 221000,
                price_range_low = 208000,
                price_range_high = 233000,
                latitude = 29.475962,
                longitude = -98.351442,
                comparables = [
                    rentcast_client.models.value_estimate_200_response_comparables_inner.value_estimate_200_response_comparables_inner(
                        id = '5014-Fern-Lk,-San-Antonio,-TX-78244', 
                        formatted_address = '5014 Fern Lk, San Antonio, TX 78244', 
                        address_line1 = '5014 Fern Lk', 
                        address_line2 = null, 
                        city = 'San Antonio', 
                        state = 'TX', 
                        zip_code = '78244', 
                        county = 'Bexar', 
                        latitude = 29.471777, 
                        longitude = -98.350172, 
                        property_type = 'Single Family', 
                        bedrooms = 4, 
                        bathrooms = 2, 
                        square_footage = 1747, 
                        lot_size = 6316, 
                        year_built = 1986, 
                        price = 229900, 
                        listing_type = 'Standard', 
                        listed_date = '2024-04-03T00:00:00.000Z', 
                        removed_date = '2024-05-26T00:00:00.000Z', 
                        last_seen_date = '2024-05-25T13:11:55.018Z', 
                        days_on_market = 53, 
                        distance = 0.2994, 
                        days_old = 127, 
                        correlation = 0.9822, )
                    ]
            )
        else:
            return RentcastValueEstimate200Response(
        )
        """

    def testRentcastValueEstimate200Response(self):
        """Test RentcastValueEstimate200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_value_estimate200_response_subject_property import RentcastValueEstimate200ResponseSubjectProperty

class TestRentcastValueEstimate200ResponseSubjectProperty(unittest.TestCase):
    """RentcastValueEstimate200ResponseSubjectProperty unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastValueEstimate200ResponseSubjectProperty:
        """Test RentcastValueEstimate200ResponseSubjectProperty
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastValueEstimate200ResponseSubjectProperty`
        """
        model = RentcastValueEstimate200ResponseSubjectProperty()
        if include_optional:
            return RentcastValueEstimate200ResponseSubjectProperty(
                id = '5500-Grand-Lake-Dr,-San-Antonio,-TX-78244',
                formatted_address = '5500 Grand Lake Dr, San Antonio, TX 78244',
                address_line1 = '5500 Grand Lake Dr',
                address_line2 = '',
                city = 'San Antonio',
                state = 'TX',
                state_fips = '48',
                zip_code = '78244',
                county = 'Bexar',
                county_fips = '029',
                latitude = 29.476011,
                longitude = -98.351454,
                property_type = 'Single Family',
                bedrooms = 3,
                bathrooms = 2,
                square_footage = 1878,
                lot_size = 8843,
                year_built = 1973,
                last_sale_date = '2024-11-18T00:00:00.000Z',
                last_sale_price = 270000
            )
        else:
            return RentcastValueEstimate200ResponseSubjectProperty(
        )
        """

    def testRentcastValueEstimate200ResponseSubjectProperty(self):
        """Test RentcastValueEstimate200ResponseSubjectProperty"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202409 import RentcastMarketStatistics200ResponseRentalDataHistory202409

class TestRentcastMarketStatistics200ResponseRentalDataHistory202409(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202409 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202409:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202409
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202409`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202409()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202409(
                var_date = '2024-09-01T00:00:00.000Z',
                average_rent = 1536,
                median_rent = 1550,
                min_rent = 750,
                max_rent = 2800,
                average_rent_per_square_foot = 1.38,
                median_rent_per_square_foot = 1.33,
                min_rent_per_square_foot = 0.86,
                max_rent_per_square_foot = 2.52,
                average_square_footage = 1180,
                median_square_footage = 1120,
                min_square_footage = 590,
                max_square_footage = 2100,
                average_days_on_market = 32.03,
                median_days_on_market = 8,
                min_days_on_market = 1,
                max_days_on_market = 365,
                new_listings = 33,
                total_listings = 80,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_rental_data_history_2024_09_data_by_property_type_inner.market_statistics_200_response_rentalData_history_2024_09_dataByPropertyType_inner(
                        property_type = 'Apartment', 
                        average_rent = 1148, 
                        median_rent = 975, 
                        min_rent = 750, 
                        max_rent = 1975, 
                        average_rent_per_square_foot = 1.25, 
                        median_rent_per_square_foot = 1.07, 
                        min_rent_per_square_foot = 1.03, 
                        max_rent_per_square_foot = 1.59, 
                        average_square_footage = 949, 
                        median_square_footage = 850, 
                        min_square_footage = 650, 
                        max_square_footage = 1560, 
                        average_days_on_market = 18.69, 
                        median_days_on_market = 17, 
                        min_days_on_market = 1, 
                        max_days_on_market = 80, 
                        new_listings = 7, 
                        total_listings = 14, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_rental_data_history_2024_09_data_by_bedrooms_inner.market_statistics_200_response_rentalData_history_2024_09_dataByBedrooms_inner(
                        bedrooms = 1, 
                        average_rent = 899, 
                        median_rent = 850, 
                        min_rent = 750, 
                        max_rent = 1300, 
                        average_rent_per_square_foot = 1.35, 
                        median_rent_per_square_foot = 1.37, 
                        min_rent_per_square_foot = 1.06, 
                        max_rent_per_square_foot = 1.57, 
                        average_square_footage = 733, 
                        median_square_footage = 675, 
                        min_square_footage = 590, 
                        max_square_footage = 950, 
                        average_days_on_market = 27.86, 
                        median_days_on_market = 21, 
                        min_days_on_market = 1, 
                        max_days_on_market = 80, 
                        new_listings = 3, 
                        total_listings = 8, )
                    ]
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202409(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202409(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202409"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202507_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseSaleDataHistory202507DataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202507_data_by_property_type_inner import RentcastMarketStatistics200ResponseSaleDataHistory202507DataByPropertyTypeInner
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class RentcastMarketStatistics200ResponseSaleDataHistory202507(BaseModel):
    """
    RentcastMarketStatistics200ResponseSaleDataHistory202507
    """ # noqa: E501
    var_date: Optional[datetime] = Field(default=None, alias="date")
    average_price: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="averagePrice")
    median_price: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="medianPrice")
    min_price: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="minPrice")
    max_price: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxPrice")
    average_price_per_square_foot: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="averagePricePerSquareFoot")
    median_price_per_square_foot: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="medianPricePerSquareFoot")
    min_price_per_square_foot: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="minPricePerSquareFoot")
    max_price_per_square_foot: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxPricePerSquareFoot")
    average_square_footage: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="averageSquareFootage")
    median_square_footage: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="medianSquareFootage")
    min_square_footage: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="minSquareFootage")
    max_square_footage: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxSquareFootage")
    average_days_on_market: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="averageDaysOnMarket")
    median_days_on_market: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="medianDaysOnMarket")
    min_days_on_market: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="minDaysOnMarket")
    max_days_on_market: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxDaysOnMarket")
    new_listings: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="newListings")
    total_listings: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalListings")
    data_by_property_type: Optional[List[RentcastMarketStatistics200ResponseSaleDataHistory202507DataByPropertyTypeInner]] = Field(default=None, alias="dataByPropertyType")
    data_by_bedrooms: Optional[List[RentcastMarketStatistics200ResponseSaleDataHistory202507DataByBedroomsInner]] = Field(default=None, alias="dataByBedrooms")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["date", "averagePrice", "medianPrice", "minPrice", "maxPrice", "averagePricePerSquareFoot", "medianPricePerSquareFoot", "minPricePerSquareFoot", "maxPricePerSquareFoot", "averageSquareFootage", "medianSquareFootage", "minSquareFootage", "maxSquareFootage", "averageDaysOnMarket", "medianDaysOnMarket", "minDaysOnMarket", "maxDaysOnMarket", "newListings", "totalListings", "dataByPropertyType", "dataByBedrooms"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RentcastMarketStatistics200ResponseSaleDataHistory202507 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in data_by_property_type (list)
        _items = []
        if self.data_by_property_type:
            for _item_data_by_property_type in self.data_by_property_type:
                if _item_data_by_property_type:
                    _items.append(_item_data_by_property_type.to_dict())
            _dict['dataByPropertyType'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in data_by_bedrooms (list)
        _items = []
        if self.data_by_bedrooms:
            for _item_data_by_bedrooms in self.data_by_bedrooms:
                if _item_data_by_bedrooms:
                    _items.append(_item_data_by_bedrooms.to_dict())
            _dict['dataByBedrooms'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RentcastMarketStatistics200ResponseSaleDataHistory202507 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "date": obj.get("date"),
            "averagePrice": obj.get("averagePrice") if obj.get("averagePrice") is not None else None,
            "medianPrice": obj.get("medianPrice") if obj.get("medianPrice") is not None else None,
            "minPrice": obj.get("minPrice") if obj.get("minPrice") is not None else None,
            "maxPrice": obj.get("maxPrice") if obj.get("maxPrice") is not None else None,
            "averagePricePerSquareFoot": obj.get("averagePricePerSquareFoot") if obj.get("averagePricePerSquareFoot") is not None else None,
            "medianPricePerSquareFoot": obj.get("medianPricePerSquareFoot") if obj.get("medianPricePerSquareFoot") is not None else None,
            "minPricePerSquareFoot": obj.get("minPricePerSquareFoot") if obj.get("minPricePerSquareFoot") is not None else None,
            "maxPricePerSquareFoot": obj.get("maxPricePerSquareFoot") if obj.get("maxPricePerSquareFoot") is not None else None,
            "averageSquareFootage": obj.get("averageSquareFootage") if obj.get("averageSquareFootage") is not None else None,
            "medianSquareFootage": obj.get("medianSquareFootage") if obj.get("medianSquareFootage") is not None else None,
            "minSquareFootage": obj.get("minSquareFootage") if obj.get("minSquareFootage") is not None else None,
            "maxSquareFootage": obj.get("maxSquareFootage") if obj.get("maxSquareFootage") is not None else None,
            "averageDaysOnMarket": obj.get("averageDaysOnMarket") if obj.get("averageDaysOnMarket") is not None else None,
            "medianDaysOnMarket": obj.get("medianDaysOnMarket") if obj.get("medianDaysOnMarket") is not None else None,
            "minDaysOnMarket": obj.get("minDaysOnMarket") if obj.get("minDaysOnMarket") is not None else None,
            "maxDaysOnMarket": obj.get("maxDaysOnMarket") if obj.get("maxDaysOnMarket") is not None else None,
            "newListings": obj.get("newListings") if obj.get("newListings") is not None else None,
            "totalListings": obj.get("totalListings") if obj.get("totalListings") is not None else None,
            "dataByPropertyType": [RentcastMarketStatistics200ResponseSaleDataHistory202507DataByPropertyTypeInner.from_dict(_item) for _item in obj["dataByPropertyType"]] if obj.get("dataByPropertyType") is not None else None,
            "dataByBedrooms": [RentcastMarketStatistics200ResponseSaleDataHistory202507DataByBedroomsInner.from_dict(_item) for _item in obj["dataByBedrooms"]] if obj.get("dataByBedrooms") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from rentcast_client.models.rentcast_property_records200_response_inner_features import RentcastPropertyRecords200ResponseInnerFeatures
from rentcast_client.models.rentcast_property_records200_response_inner_history import RentcastPropertyRecords200ResponseInnerHistory
from rentcast_client.models.rentcast_property_records200_response_inner_hoa import RentcastPropertyRecords200ResponseInnerHoa
from rentcast_client.models.rentcast_property_records200_response_inner_owner import RentcastPropertyRecords200ResponseInnerOwner
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes import RentcastPropertyRecords200ResponseInnerPropertyTaxes
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments import RentcastPropertyRecords200ResponseInnerTaxAssessments
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class RentcastPropertyRecords200ResponseInner(BaseModel):
    """
    RentcastPropertyRecords200ResponseInner
    """ # noqa: E501
    id: Optional[StrictStr] = None
    formatted_address: Optional[StrictStr] = Field(default=None, alias="formattedAddress")
    address_line1: Optional[StrictStr] = Field(default=None, alias="addressLine1")
    address_line2: Optional[StrictStr] = Field(default=None, alias="addressLine2")
    city: Optional[StrictStr] = None
    state: Optional[StrictStr] = None
    state_fips: Optional[StrictStr] = Field(default=None, alias="stateFips")
    zip_code: Optional[StrictStr] = Field(default=None, alias="zipCode")
    county: Optional[StrictStr] = None
    county_fips: Optional[StrictStr] = Field(default=None, alias="countyFips")
    latitude: Optional[Union[StrictFloat, StrictInt]] = None
    longitude: Optional[Union[StrictFloat, StrictInt]] = None
    property_type: Optional[StrictStr] = Field(default=None, alias="propertyType")
    bedrooms: Optional[Union[StrictFloat, StrictInt]] = None
    bathrooms: Optional[Union[StrictFloat, StrictInt]] = None
    square_footage: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="squareFootage")
    lot_size: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="lotSize")
    year_built: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="yearBuilt")
    assessor_id: Optional[StrictStr] = Field(default=None, alias="assessorID")
    legal_description: Optional[StrictStr] = Field(default=None, alias="legalDescription")
    subdivision: Optional[StrictStr] = None
    zoning: Optional[StrictStr] = None
    last_sale_date: Optional[datetime] = Field(default=None, alias="lastSaleDate")
    last_sale_price: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="lastSalePrice")
    hoa: Optional[RentcastPropertyRecords200ResponseInnerHoa] = None
    features: Optional[RentcastPropertyRecords200ResponseInnerFeatures] = None
    tax_assessments: Optional[RentcastPropertyRecords200ResponseInnerTaxAssessments] = Field(default=None, alias="taxAssessments")
    property_taxes: Optional[RentcastPropertyRecords200ResponseInnerPropertyTaxes] = Field(default=None, alias="propertyTaxes")
    history: Optional[RentcastPropertyRecords200ResponseInnerHistory] = None
    owner: Optional[RentcastPropertyRecords200ResponseInnerOwner] = None
    owner_occupied: Optional[StrictBool] = Field(default=False, alias="ownerOccupied")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["id", "formattedAddress", "addressLine1", "addressLine2", "city", "state", "stateFips", "zipCode", "county", "countyFips", "latitude", "longitude", "propertyType", "bedrooms", "bathrooms", "squareFootage", "lotSize", "yearBuilt", "assessorID", "legalDescription", "subdivision", "zoning", "lastSaleDate", "lastSalePrice", "hoa", "features", "taxAssessments", "propertyTaxes", "history", "owner", "ownerOccupied"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RentcastPropertyRecords200ResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of hoa
        if self.hoa:
            _dict['hoa'] = self.hoa.to_dict()
        # override the default output from pydantic by calling `to_dict()` of features
        if self.features:
            _dict['features'] = self.features.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tax_assessments
        if self.tax_assessments:
            _dict['taxAssessments'] = self.tax_assessments.to_dict()
        # override the default output from pydantic by calling `to_dict()` of property_taxes
        if self.property_taxes:
            _dict['propertyTaxes'] = self.property_taxes.to_dict()
        # override the default output from pydantic by calling `to_dict()` of history
        if self.history:
            _dict['history'] = self.history.to_dict()
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict['owner'] = self.owner.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RentcastPropertyRecords200ResponseInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "formattedAddress": obj.get("formattedAddress"),
            "addressLine1": obj.get("addressLine1"),
            "addressLine2": obj.get("addressLine2"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "stateFips": obj.get("stateFips"),
            "zipCode": obj.get("zipCode"),
            "county": obj.get("county"),
            "countyFips": obj.get("countyFips"),
            "latitude": obj.get("latitude") if obj.get("latitude") is not None else None,
            "longitude": obj.get("longitude") if obj.get("longitude") is not None else None,
            "propertyType": obj.get("propertyType"),
            "bedrooms": obj.get("bedrooms") if obj.get("bedrooms") is not None else None,
            "bathrooms": obj.get("bathrooms") if obj.get("bathrooms") is not None else None,
            "squareFootage": obj.get("squareFootage") if obj.get("squareFootage") is not None else None,
            "lotSize": obj.get("lotSize") if obj.get("lotSize") is not None else None,
            "yearBuilt": obj.get("yearBuilt") if obj.get("yearBuilt") is not None else None,
            "assessorID": obj.get("assessorID"),
            "legalDescription": obj.get("legalDescription"),
            "subdivision": obj.get("subdivision"),
            "zoning": obj.get("zoning"),
            "lastSaleDate": obj.get("lastSaleDate"),
            "lastSalePrice": obj.get("lastSalePrice") if obj.get("lastSalePrice") is not None else None,
            "hoa": RentcastPropertyRecords200ResponseInnerHoa.from_dict(obj["hoa"]) if obj.get("hoa") is not None else None,
            "features": RentcastPropertyRecords200ResponseInnerFeatures.from_dict(obj["features"]) if obj.get("features") is not None else None,
            "taxAssessments": RentcastPropertyRecords200ResponseInnerTaxAssessments.from_dict(obj["taxAssessments"]) if obj.get("taxAssessments") is not None else None,
            "propertyTaxes": RentcastPropertyRecords200ResponseInnerPropertyTaxes.from_dict(obj["propertyTaxes"]) if obj.get("propertyTaxes") is not None else None,
            "history": RentcastPropertyRecords200ResponseInnerHistory.from_dict(obj["history"]) if obj.get("history") is not None else None,
            "owner": RentcastPropertyRecords200ResponseInnerOwner.from_dict(obj["owner"]) if obj.get("owner") is not None else None,
            "ownerOccupied": obj.get("ownerOccupied") if obj.get("ownerOccupied") is not None else False
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

# flake8: noqa

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2.1.1"

# Define package exports
__all__ = [
    "DefaultRentcast",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "RentcastMarketStatistics200Response",
    "RentcastMarketStatistics200ResponseRentalData",
    "RentcastMarketStatistics200ResponseRentalDataDataByBedroomsInner",
    "RentcastMarketStatistics200ResponseRentalDataDataByPropertyTypeInner",
    "RentcastMarketStatistics200ResponseRentalDataHistory",
    "RentcastMarketStatistics200ResponseRentalDataHistory202506",
    "RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner",
    "RentcastMarketStatistics200ResponseRentalDataHistory202506DataByPropertyTypeInner",
    "RentcastMarketStatistics200ResponseRentalDataHistory202507",
    "RentcastMarketStatistics200ResponseRentalDataHistory202507DataByBedroomsInner",
    "RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner",
    "RentcastMarketStatistics200ResponseRentalDataHistory202508",
    "RentcastMarketStatistics200ResponseRentalDataHistory202508DataByPropertyTypeInner",
    "RentcastMarketStatistics200ResponseSaleData",
    "RentcastMarketStatistics200ResponseSaleDataDataByBedroomsInner",
    "RentcastMarketStatistics200ResponseSaleDataDataByPropertyTypeInner",
    "RentcastMarketStatistics200ResponseSaleDataHistory",
    "RentcastMarketStatistics200ResponseSaleDataHistory202506",
    "RentcastMarketStatistics200ResponseSaleDataHistory202506DataByBedroomsInner",
    "RentcastMarketStatistics200ResponseSaleDataHistory202506DataByPropertyTypeInner",
    "RentcastMarketStatistics200ResponseSaleDataHistory202507",
    "RentcastMarketStatistics200ResponseSaleDataHistory202507DataByBedroomsInner",
    "RentcastMarketStatistics200ResponseSaleDataHistory202507DataByPropertyTypeInner",
    "RentcastMarketStatistics200ResponseSaleDataHistory202508",
    "RentcastPropertyRecords200ResponseInner",
    "RentcastPropertyRecords200ResponseInnerFeatures",
    "RentcastPropertyRecords200ResponseInnerHistory",
    "RentcastPropertyRecords200ResponseInnerHistory20171019",
    "RentcastPropertyRecords200ResponseInnerHistory20241118",
    "RentcastPropertyRecords200ResponseInnerHoa",
    "RentcastPropertyRecords200ResponseInnerOwner",
    "RentcastPropertyRecords200ResponseInnerOwnerMailingAddress",
    "RentcastPropertyRecords200ResponseInnerPropertyTaxes",
    "RentcastPropertyRecords200ResponseInnerPropertyTaxes2020",
    "RentcastPropertyRecords200ResponseInnerPropertyTaxes2021",
    "RentcastPropertyRecords200ResponseInnerPropertyTaxes2022",
    "RentcastPropertyRecords200ResponseInnerPropertyTaxes2023",
    "RentcastPropertyRecords200ResponseInnerPropertyTaxes2024",
    "RentcastPropertyRecords200ResponseInnerTaxAssessments",
    "RentcastPropertyRecords200ResponseInnerTaxAssessments2020",
    "RentcastPropertyRecords200ResponseInnerTaxAssessments2021",
    "RentcastPropertyRecords200ResponseInnerTaxAssessments2022",
    "RentcastPropertyRecords200ResponseInnerTaxAssessments2023",
    "RentcastPropertyRecords200ResponseInnerTaxAssessments2024",
    "RentcastPropertyRecords401Response",
    "RentcastRentEstimateLongTerm200Response",
    "RentcastRentEstimateLongTerm200ResponseComparablesInner",
    "RentcastRentalListingsLongTerm200ResponseInner",
    "RentcastRentalListingsLongTerm200ResponseInnerHistory",
    "RentcastRentalListingsLongTerm200ResponseInnerHistory20240918",
    "RentcastRentalListingsLongTerm200ResponseInnerHoa",
    "RentcastRentalListingsLongTerm200ResponseInnerListingAgent",
    "RentcastRentalListingsLongTerm200ResponseInnerListingOffice",
    "RentcastSaleListingById200Response",
    "RentcastSaleListings200ResponseInner",
    "RentcastSaleListings200ResponseInnerHistory",
    "RentcastSaleListings200ResponseInnerHistory20240624",
    "RentcastSaleListings200ResponseInnerHoa",
    "RentcastSaleListings200ResponseInnerListingAgent",
    "RentcastSaleListings200ResponseInnerListingOffice",
    "RentcastValueEstimate200Response",
    "RentcastValueEstimate200ResponseComparablesInner",
    "RentcastValueEstimate200ResponseSubjectProperty",
    "RentcastValueEstimate401Response",
]

# import apis into sdk package
from rentcast_client.api.default_rentcast import DefaultRentcast as DefaultRentcast

# import ApiClient
from rentcast_client.api_response import ApiResponse as ApiResponse
from rentcast_client.api_client import ApiClient as ApiClient
from rentcast_client.configuration import Configuration as Configuration
from rentcast_client.exceptions import OpenApiException as OpenApiException
from rentcast_client.exceptions import ApiTypeError as ApiTypeError
from rentcast_client.exceptions import ApiValueError as ApiValueError
from rentcast_client.exceptions import ApiKeyError as ApiKeyError
from rentcast_client.exceptions import ApiAttributeError as ApiAttributeError
from rentcast_client.exceptions import ApiException as ApiException

# import models into sdk package
from rentcast_client.models.rentcast_market_statistics200_response import RentcastMarketStatistics200Response as RentcastMarketStatistics200Response
from rentcast_client.models.rentcast_market_statistics200_response_rental_data import RentcastMarketStatistics200ResponseRentalData as RentcastMarketStatistics200ResponseRentalData
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseRentalDataDataByBedroomsInner as RentcastMarketStatistics200ResponseRentalDataDataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_data_by_property_type_inner import RentcastMarketStatistics200ResponseRentalDataDataByPropertyTypeInner as RentcastMarketStatistics200ResponseRentalDataDataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history import RentcastMarketStatistics200ResponseRentalDataHistory as RentcastMarketStatistics200ResponseRentalDataHistory
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202506 import RentcastMarketStatistics200ResponseRentalDataHistory202506 as RentcastMarketStatistics200ResponseRentalDataHistory202506
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202506_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner as RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202506_data_by_property_type_inner import RentcastMarketStatistics200ResponseRentalDataHistory202506DataByPropertyTypeInner as RentcastMarketStatistics200ResponseRentalDataHistory202506DataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202507 import RentcastMarketStatistics200ResponseRentalDataHistory202507 as RentcastMarketStatistics200ResponseRentalDataHistory202507
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202507_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseRentalDataHistory202507DataByBedroomsInner as RentcastMarketStatistics200ResponseRentalDataHistory202507DataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202507_data_by_property_type_inner import RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner as RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202508 import RentcastMarketStatistics200ResponseRentalDataHistory202508 as RentcastMarketStatistics200ResponseRentalDataHistory202508
from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202508_data_by_property_type_inner import RentcastMarketStatistics200ResponseRentalDataHistory202508DataByPropertyTypeInner as RentcastMarketStatistics200ResponseRentalDataHistory202508DataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data import RentcastMarketStatistics200ResponseSaleData as RentcastMarketStatistics200ResponseSaleData
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseSaleDataDataByBedroomsInner as RentcastMarketStatistics200ResponseSaleDataDataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_data_by_property_type_inner import RentcastMarketStatistics200ResponseSaleDataDataByPropertyTypeInner as RentcastMarketStatistics200ResponseSaleDataDataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history import RentcastMarketStatistics200ResponseSaleDataHistory as RentcastMarketStatistics200ResponseSaleDataHistory
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202506 import RentcastMarketStatistics200ResponseSaleDataHistory202506 as RentcastMarketStatistics200ResponseSaleDataHistory202506
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202506_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseSaleDataHistory202506DataByBedroomsInner as RentcastMarketStatistics200ResponseSaleDataHistory202506DataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202506_data_by_property_type_inner import RentcastMarketStatistics200ResponseSaleDataHistory202506DataByPropertyTypeInner as RentcastMarketStatistics200ResponseSaleDataHistory202506DataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202507 import RentcastMarketStatistics200ResponseSaleDataHistory202507 as RentcastMarketStatistics200ResponseSaleDataHistory202507
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202507_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseSaleDataHistory202507DataByBedroomsInner as RentcastMarketStatistics200ResponseSaleDataHistory202507DataByBedroomsInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202507_data_by_property_type_inner import RentcastMarketStatistics200ResponseSaleDataHistory202507DataByPropertyTypeInner as RentcastMarketStatistics200ResponseSaleDataHistory202507DataByPropertyTypeInner
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202508 import RentcastMarketStatistics200ResponseSaleDataHistory202508 as RentcastMarketStatistics200ResponseSaleDataHistory202508
from rentcast_client.models.rentcast_property_records200_response_inner import RentcastPropertyRecords200ResponseInner as RentcastPropertyRecords200ResponseInner
from rentcast_client.models.rentcast_property_records200_response_inner_features import RentcastPropertyRecords200ResponseInnerFeatures as RentcastPropertyRecords200ResponseInnerFeatures
from rentcast_client.models.rentcast_property_records200_response_inner_history import RentcastPropertyRecords200ResponseInnerHistory as RentcastPropertyRecords200ResponseInnerHistory
from rentcast_client.models.rentcast_property_records200_response_inner_history20171019 import RentcastPropertyRecords200ResponseInnerHistory20171019 as RentcastPropertyRecords200ResponseInnerHistory20171019
from rentcast_client.models.rentcast_property_records200_response_inner_history20241118 import RentcastPropertyRecords200ResponseInnerHistory20241118 as RentcastPropertyRecords200ResponseInnerHistory20241118
from rentcast_client.models.rentcast_property_records200_response_inner_hoa import RentcastPropertyRecords200ResponseInnerHoa as RentcastPropertyRecords200ResponseInnerHoa
from rentcast_client.models.rentcast_property_records200_response_inner_owner import RentcastPropertyRecords200ResponseInnerOwner as RentcastPropertyRecords200ResponseInnerOwner
from rentcast_client.models.rentcast_property_records200_response_inner_owner_mailing_address import RentcastPropertyRecords200ResponseInnerOwnerMailingAddress as RentcastPropertyRecords200ResponseInnerOwnerMailingAddress
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes import RentcastPropertyRecords200ResponseInnerPropertyTaxes as RentcastPropertyRecords200ResponseInnerPropertyTaxes
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2020 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2020 as RentcastPropertyRecords200ResponseInnerPropertyTaxes2020
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2021 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2021 as RentcastPropertyRecords200ResponseInnerPropertyTaxes2021
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2022 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2022 as RentcastPropertyRecords200ResponseInnerPropertyTaxes2022
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2023 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2023 as RentcastPropertyRecords200ResponseInnerPropertyTaxes2023
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes2024 import RentcastPropertyRecords200ResponseInnerPropertyTaxes2024 as RentcastPropertyRecords200ResponseInnerPropertyTaxes2024
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments import RentcastPropertyRecords200ResponseInnerTaxAssessments as RentcastPropertyRecords200ResponseInnerTaxAssessments
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments2020 import RentcastPropertyRecords200ResponseInnerTaxAssessments2020 as RentcastPropertyRecords200ResponseInnerTaxAssessments2020
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments2021 import RentcastPropertyRecords200ResponseInnerTaxAssessments2021 as RentcastPropertyRecords200ResponseInnerTaxAssessments2021
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments2022 import RentcastPropertyRecords200ResponseInnerTaxAssessments2022 as RentcastPropertyRecords200ResponseInnerTaxAssessments2022
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments2023 import RentcastPropertyRecords200ResponseInnerTaxAssessments2023 as RentcastPropertyRecords200ResponseInnerTaxAssessments2023
from rentcast_client.models.rentcast_property_records200_response_inner_tax_assessments2024 import RentcastPropertyRecords200ResponseInnerTaxAssessments2024 as RentcastPropertyRecords200ResponseInnerTaxAssessments2024
from rentcast_client.models.rentcast_property_records401_response import RentcastPropertyRecords401Response as RentcastPropertyRecords401Response
from rentcast_client.models.rentcast_rent_estimate_long_term200_response import RentcastRentEstimateLongTerm200Response as RentcastRentEstimateLongTerm200Response
from rentcast_client.models.rentcast_rent_estimate_long_term200_response_comparables_inner import RentcastRentEstimateLongTerm200ResponseComparablesInner as RentcastRentEstimateLongTerm200ResponseComparablesInner
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner import RentcastRentalListingsLongTerm200ResponseInner as RentcastRentalListingsLongTerm200ResponseInner
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_history import RentcastRentalListingsLongTerm200ResponseInnerHistory as RentcastRentalListingsLongTerm200ResponseInnerHistory
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_history20240918 import RentcastRentalListingsLongTerm200ResponseInnerHistory20240918 as RentcastRentalListingsLongTerm200ResponseInnerHistory20240918
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_hoa import RentcastRentalListingsLongTerm200ResponseInnerHoa as RentcastRentalListingsLongTerm200ResponseInnerHoa
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_listing_agent import RentcastRentalListingsLongTerm200ResponseInnerListingAgent as RentcastRentalListingsLongTerm200ResponseInnerListingAgent
from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_listing_office import RentcastRentalListingsLongTerm200ResponseInnerListingOffice as RentcastRentalListingsLongTerm200ResponseInnerListingOffice
from rentcast_client.models.rentcast_sale_listing_by_id200_response import RentcastSaleListingById200Response as RentcastSaleListingById200Response
from rentcast_client.models.rentcast_sale_listings200_response_inner import RentcastSaleListings200ResponseInner as RentcastSaleListings200ResponseInner
from rentcast_client.models.rentcast_sale_listings200_response_inner_history import RentcastSaleListings200ResponseInnerHistory as RentcastSaleListings200ResponseInnerHistory
from rentcast_client.models.rentcast_sale_listings200_response_inner_history20240624 import RentcastSaleListings200ResponseInnerHistory20240624 as RentcastSaleListings200ResponseInnerHistory20240624
from rentcast_client.models.rentcast_sale_listings200_response_inner_hoa import RentcastSaleListings200ResponseInnerHoa as RentcastSaleListings200ResponseInnerHoa
from rentcast_client.models.rentcast_sale_listings200_response_inner_listing_agent import RentcastSaleListings200ResponseInnerListingAgent as RentcastSaleListings200ResponseInnerListingAgent
from rentcast_client.models.rentcast_sale_listings200_response_inner_listing_office import RentcastSaleListings200ResponseInnerListingOffice as RentcastSaleListings200ResponseInnerListingOffice
from rentcast_client.models.rentcast_value_estimate200_response import RentcastValueEstimate200Response as RentcastValueEstimate200Response
from rentcast_client.models.rentcast_value_estimate200_response_comparables_inner import RentcastValueEstimate200ResponseComparablesInner as RentcastValueEstimate200ResponseComparablesInner
from rentcast_client.models.rentcast_value_estimate200_response_subject_property import RentcastValueEstimate200ResponseSubjectProperty as RentcastValueEstimate200ResponseSubjectProperty
from rentcast_client.models.rentcast_value_estimate401_response import RentcastValueEstimate401Response as RentcastValueEstimate401Response




# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_property_records200_response_inner_features import RentcastPropertyRecords200ResponseInnerFeatures

class TestRentcastPropertyRecords200ResponseInnerFeatures(unittest.TestCase):
    """RentcastPropertyRecords200ResponseInnerFeatures unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastPropertyRecords200ResponseInnerFeatures:
        """Test RentcastPropertyRecords200ResponseInnerFeatures
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastPropertyRecords200ResponseInnerFeatures`
        """
        model = RentcastPropertyRecords200ResponseInnerFeatures()
        if include_optional:
            return RentcastPropertyRecords200ResponseInnerFeatures(
                architecture_type = 'Contemporary',
                cooling = True,
                cooling_type = 'Central',
                exterior_type = 'Wood',
                fireplace = True,
                fireplace_type = 'Masonry',
                floor_count = 1,
                foundation_type = 'Slab / Mat / Raft',
                garage = True,
                garage_spaces = 2,
                garage_type = 'Garage',
                heating = True,
                heating_type = 'Forced Air',
                pool = True,
                pool_type = 'Concrete',
                roof_type = 'Asphalt',
                room_count = 5,
                unit_count = 1,
                view_type = 'City'
            )
        else:
            return RentcastPropertyRecords200ResponseInnerFeatures(
        )
        """

    def testRentcastPropertyRecords200ResponseInnerFeatures(self):
        """Test RentcastPropertyRecords200ResponseInnerFeatures"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202506 import RentcastMarketStatistics200ResponseSaleDataHistory202506
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202507 import RentcastMarketStatistics200ResponseSaleDataHistory202507
from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202508 import RentcastMarketStatistics200ResponseSaleDataHistory202508
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class RentcastMarketStatistics200ResponseSaleDataHistory(BaseModel):
    """
    RentcastMarketStatistics200ResponseSaleDataHistory
    """ # noqa: E501
    var_2025_06: Optional[RentcastMarketStatistics200ResponseSaleDataHistory202506] = Field(default=None, alias="2025-06")
    var_2025_07: Optional[RentcastMarketStatistics200ResponseSaleDataHistory202507] = Field(default=None, alias="2025-07")
    var_2025_08: Optional[RentcastMarketStatistics200ResponseSaleDataHistory202508] = Field(default=None, alias="2025-08")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["2025-06", "2025-07", "2025-08"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RentcastMarketStatistics200ResponseSaleDataHistory from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of var_2025_06
        if self.var_2025_06:
            _dict['2025-06'] = self.var_2025_06.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_2025_07
        if self.var_2025_07:
            _dict['2025-07'] = self.var_2025_07.to_dict()
        # override the default output from pydantic by calling `to_dict()` of var_2025_08
        if self.var_2025_08:
            _dict['2025-08'] = self.var_2025_08.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RentcastMarketStatistics200ResponseSaleDataHistory from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "2025-06": RentcastMarketStatistics200ResponseSaleDataHistory202506.from_dict(obj["2025-06"]) if obj.get("2025-06") is not None else None,
            "2025-07": RentcastMarketStatistics200ResponseSaleDataHistory202507.from_dict(obj["2025-07"]) if obj.get("2025-07") is not None else None,
            "2025-08": RentcastMarketStatistics200ResponseSaleDataHistory202508.from_dict(obj["2025-08"]) if obj.get("2025-08") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_sale_listings200_response_inner import RentcastSaleListings200ResponseInner

class TestRentcastSaleListings200ResponseInner(unittest.TestCase):
    """RentcastSaleListings200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastSaleListings200ResponseInner:
        """Test RentcastSaleListings200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastSaleListings200ResponseInner`
        """
        model = RentcastSaleListings200ResponseInner()
        if include_optional:
            return RentcastSaleListings200ResponseInner(
                id = '3821-Hargis-St,-Austin,-TX-78723',
                formatted_address = '3821 Hargis St, Austin, TX 78723',
                address_line1 = '3821 Hargis St',
                address_line2 = None,
                city = 'Austin',
                state = 'TX',
                zip_code = '78723',
                county = 'Travis',
                latitude = 30.290643,
                longitude = -97.701547,
                property_type = 'Single Family',
                bedrooms = 4,
                bathrooms = 2.5,
                square_footage = 2345,
                lot_size = 3284,
                year_built = 2008,
                hoa = rentcast_client.models.sale_listings_200_response_inner_hoa.sale_listings_200_response_inner_hoa(
                    fee = 65, ),
                status = 'Active',
                price = 899000,
                listing_type = 'Standard',
                listed_date = '2024-06-24T00:00:00.000Z',
                removed_date = None,
                created_date = '2021-06-25T00:00:00.000Z',
                last_seen_date = '2024-09-30T13:11:47.157Z',
                days_on_market = 99,
                mls_name = 'UnlockMLS',
                mls_number = '5519228',
                listing_agent = rentcast_client.models.sale_listings_200_response_inner_listing_agent.sale_listings_200_response_inner_listingAgent(
                    name = 'Jennifer Welch', 
                    phone = '5124313110', 
                    email = 'jennifer@gottesmanresidential.com', 
                    website = 'https://www.gottesmanresidential.com', ),
                listing_office = rentcast_client.models.sale_listings_200_response_inner_listing_office.sale_listings_200_response_inner_listingOffice(
                    name = 'Gottesman Residential R.E.', 
                    phone = '5124512422', 
                    email = 'nataliem@gottesmanresidential.com', 
                    website = 'https://www.gottesmanresidential.com', ),
                history = rentcast_client.models.sale_listings_200_response_inner_history.sale_listings_200_response_inner_history(
                    2024_06_24 = rentcast_client.models.sale_listings_200_response_inner_history_2024_06_24.sale_listings_200_response_inner_history_2024_06_24(
                        event = 'Sale Listing', 
                        price = 899000, 
                        listing_type = 'Standard', 
                        listed_date = '2024-06-24T00:00:00.000Z', 
                        removed_date = null, 
                        days_on_market = 99, ), )
            )
        else:
            return RentcastSaleListings200ResponseInner(
        )
        """

    def testRentcastSaleListings200ResponseInner(self):
        """Test RentcastSaleListings200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response import RentcastMarketStatistics200Response

class TestRentcastMarketStatistics200Response(unittest.TestCase):
    """RentcastMarketStatistics200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200Response:
        """Test RentcastMarketStatistics200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200Response`
        """
        model = RentcastMarketStatistics200Response()
        if include_optional:
            return RentcastMarketStatistics200Response(
                id = '29611',
                zip_code = '29611',
                sale_data = rentcast_client.models.market_statistics_200_response_sale_data.market_statistics_200_response_saleData(
                    last_updated_date = '2024-10-14T00:00:00.000Z', 
                    average_price = 291933, 
                    median_price = 276990, 
                    min_price = 20000, 
                    max_price = 1500000, 
                    average_price_per_square_foot = 186.53, 
                    median_price_per_square_foot = 178, 
                    min_price_per_square_foot = 64.9, 
                    max_price_per_square_foot = 500, 
                    average_square_footage = 1698, 
                    median_square_footage = 1600, 
                    min_square_footage = 610, 
                    max_square_footage = 4588, 
                    average_days_on_market = 67.21, 
                    median_days_on_market = 45, 
                    min_days_on_market = 2, 
                    max_days_on_market = 348, 
                    new_listings = 21, 
                    total_listings = 265, 
                    data_by_property_type = [
                        rentcast_client.models.market_statistics_200_response_sale_data_data_by_property_type_inner.market_statistics_200_response_saleData_dataByPropertyType_inner(
                            property_type = 'Condo', 
                            average_price = 144900, 
                            median_price = 144900, 
                            min_price = 144900, 
                            max_price = 144900, 
                            average_price_per_square_foot = 129.26, 
                            median_price_per_square_foot = 129.26, 
                            min_price_per_square_foot = 129.26, 
                            max_price_per_square_foot = 129.26, 
                            average_square_footage = 1121, 
                            median_square_footage = 1121, 
                            min_square_footage = 1121, 
                            max_square_footage = 1121, 
                            average_days_on_market = 61, 
                            median_days_on_market = 61, 
                            min_days_on_market = 61, 
                            max_days_on_market = 61, 
                            new_listings = 0, 
                            total_listings = 1, )
                        ], 
                    data_by_bedrooms = [
                        rentcast_client.models.market_statistics_200_response_sale_data_data_by_bedrooms_inner.market_statistics_200_response_saleData_dataByBedrooms_inner(
                            bedrooms = 1, 
                            average_price = 186725, 
                            median_price = 153000, 
                            min_price = 147900, 
                            max_price = 237000, 
                            average_price_per_square_foot = 240.84, 
                            median_price_per_square_foot = 191.01, 
                            min_price_per_square_foot = 184.88, 
                            max_price_per_square_foot = 342.62, 
                            average_square_footage = 795, 
                            median_square_footage = 800, 
                            min_square_footage = 610, 
                            max_square_footage = 968, 
                            average_days_on_market = 123, 
                            median_days_on_market = 56, 
                            min_days_on_market = 20, 
                            max_days_on_market = 314, 
                            new_listings = 0, 
                            total_listings = 4, )
                        ], 
                    history = rentcast_client.models.market_statistics_200_response_sale_data_history.market_statistics_200_response_saleData_history(
                        2024_08 = rentcast_client.models.market_statistics_200_response_sale_data_history_2024_08.market_statistics_200_response_saleData_history_2024_08(
                            date = '2024-08-01T00:00:00.000Z', 
                            average_price = 304256, 
                            median_price = 284900, 
                            min_price = 75000, 
                            max_price = 975000, 
                            average_price_per_square_foot = 177.79, 
                            median_price_per_square_foot = 174.82, 
                            min_price_per_square_foot = 115.81, 
                            max_price_per_square_foot = 342.62, 
                            average_square_footage = 1759, 
                            median_square_footage = 1591, 
                            min_square_footage = 610, 
                            max_square_footage = 4588, 
                            average_days_on_market = 56.94, 
                            median_days_on_market = 41, 
                            min_days_on_market = 2, 
                            max_days_on_market = 327, 
                            new_listings = 56, 
                            total_listings = 215, ), 
                        2024_09 = rentcast_client.models.market_statistics_200_response_sale_data_history_2024_09.market_statistics_200_response_saleData_history_2024_09(
                            date = '2024-09-01T00:00:00.000Z', 
                            average_price = 291174, 
                            median_price = 277990, 
                            min_price = 20000, 
                            max_price = 1500000, 
                            average_price_per_square_foot = 187.39, 
                            median_price_per_square_foot = 178, 
                            min_price_per_square_foot = 64.9, 
                            max_price_per_square_foot = 500, 
                            average_square_footage = 1695, 
                            median_square_footage = 1600, 
                            min_square_footage = 610, 
                            max_square_footage = 4588, 
                            average_days_on_market = 63.65, 
                            median_days_on_market = 41, 
                            min_days_on_market = 2, 
                            max_days_on_market = 357, 
                            new_listings = 66, 
                            total_listings = 269, ), 
                        2024_10 = rentcast_client.models.market_statistics_200_response_sale_data_history_2024_10.market_statistics_200_response_saleData_history_2024_10(
                            date = '2024-10-01T00:00:00.000Z', 
                            average_price = 291933, 
                            median_price = 276990, 
                            min_price = 20000, 
                            max_price = 1500000, 
                            average_price_per_square_foot = 186.53, 
                            median_price_per_square_foot = 178, 
                            min_price_per_square_foot = 64.9, 
                            max_price_per_square_foot = 500, 
                            average_square_footage = 1698, 
                            median_square_footage = 1600, 
                            min_square_footage = 610, 
                            max_square_footage = 4588, 
                            average_days_on_market = 67.21, 
                            median_days_on_market = 45, 
                            min_days_on_market = 2, 
                            max_days_on_market = 348, 
                            new_listings = 21, 
                            total_listings = 265, ), ), ),
                rental_data = rentcast_client.models.market_statistics_200_response_rental_data.market_statistics_200_response_rentalData(
                    last_updated_date = '2024-10-14T00:00:00.000Z', 
                    average_rent = 1521, 
                    median_rent = 1495, 
                    min_rent = 750, 
                    max_rent = 2700, 
                    average_rent_per_square_foot = 1.38, 
                    median_rent_per_square_foot = 1.3, 
                    min_rent_per_square_foot = 0.86, 
                    max_rent_per_square_foot = 2.59, 
                    average_square_footage = 1175, 
                    median_square_footage = 1100, 
                    min_square_footage = 590, 
                    max_square_footage = 2100, 
                    average_days_on_market = 25, 
                    median_days_on_market = 8, 
                    min_days_on_market = 1, 
                    max_days_on_market = 304, 
                    new_listings = 18, 
                    total_listings = 76, 
                    data_by_property_type = [
                        rentcast_client.models.market_statistics_200_response_rental_data_data_by_property_type_inner.market_statistics_200_response_rentalData_dataByPropertyType_inner(
                            property_type = 'Apartment', 
                            average_rent = 1148, 
                            median_rent = 1050, 
                            min_rent = 750, 
                            max_rent = 1975, 
                            average_rent_per_square_foot = 1.23, 
                            median_rent_per_square_foot = 1.13, 
                            min_rent_per_square_foot = 1.03, 
                            max_rent_per_square_foot = 1.59, 
                            average_square_footage = 957, 
                            median_square_footage = 950, 
                            min_square_footage = 650, 
                            max_square_footage = 1560, 
                            average_days_on_market = 17.43, 
                            median_days_on_market = 1, 
                            min_days_on_market = 1, 
                            max_days_on_market = 80, 
                            new_listings = 5, 
                            total_listings = 15, )
                        ], 
                    data_by_bedrooms = [
                        rentcast_client.models.market_statistics_200_response_rental_data_data_by_bedrooms_inner.market_statistics_200_response_rentalData_dataByBedrooms_inner(
                            bedrooms = 1, 
                            average_rent = 842, 
                            median_rent = 850, 
                            min_rent = 750, 
                            max_rent = 945, 
                            average_rent_per_square_foot = 1.35, 
                            median_rent_per_square_foot = 1.3, 
                            min_rent_per_square_foot = 1.06, 
                            max_rent_per_square_foot = 1.57, 
                            average_square_footage = 679, 
                            median_square_footage = 650, 
                            min_square_footage = 590, 
                            max_square_footage = 800, 
                            average_days_on_market = 27.33, 
                            median_days_on_market = 9, 
                            min_days_on_market = 1, 
                            max_days_on_market = 80, 
                            new_listings = 1, 
                            total_listings = 7, )
                        ], 
                    history = rentcast_client.models.market_statistics_200_response_rental_data_history.market_statistics_200_response_rentalData_history(
                        2024_08 = rentcast_client.models.market_statistics_200_response_rental_data_history_2024_08.market_statistics_200_response_rentalData_history_2024_08(
                            date = '2024-08-01T00:00:00.000Z', 
                            average_rent = 1496, 
                            median_rent = 1495, 
                            min_rent = 750, 
                            max_rent = 2800, 
                            average_rent_per_square_foot = 1.33, 
                            median_rent_per_square_foot = 1.27, 
                            min_rent_per_square_foot = 0.86, 
                            max_rent_per_square_foot = 2.52, 
                            average_square_footage = 1171, 
                            median_square_footage = 1100, 
                            min_square_footage = 650, 
                            max_square_footage = 2100, 
                            average_days_on_market = 66.49, 
                            median_days_on_market = 16, 
                            min_days_on_market = 1, 
                            max_days_on_market = 365, 
                            new_listings = 39, 
                            total_listings = 96, ), 
                        2024_09 = rentcast_client.models.market_statistics_200_response_rental_data_history_2024_09.market_statistics_200_response_rentalData_history_2024_09(
                            date = '2024-09-01T00:00:00.000Z', 
                            average_rent = 1536, 
                            median_rent = 1550, 
                            min_rent = 750, 
                            max_rent = 2800, 
                            average_rent_per_square_foot = 1.38, 
                            median_rent_per_square_foot = 1.33, 
                            min_rent_per_square_foot = 0.86, 
                            max_rent_per_square_foot = 2.52, 
                            average_square_footage = 1180, 
                            median_square_footage = 1120, 
                            min_square_footage = 590, 
                            max_square_footage = 2100, 
                            average_days_on_market = 32.03, 
                            median_days_on_market = 8, 
                            min_days_on_market = 1, 
                            max_days_on_market = 365, 
                            new_listings = 33, 
                            total_listings = 80, ), 
                        2024_10 = rentcast_client.models.market_statistics_200_response_rental_data_history_2024_10.market_statistics_200_response_rentalData_history_2024_10(
                            date = '2024-10-01T00:00:00.000Z', 
                            average_rent = 1521, 
                            median_rent = 1495, 
                            min_rent = 750, 
                            max_rent = 2700, 
                            average_rent_per_square_foot = 1.38, 
                            median_rent_per_square_foot = 1.3, 
                            min_rent_per_square_foot = 0.86, 
                            max_rent_per_square_foot = 2.59, 
                            average_square_footage = 1175, 
                            median_square_footage = 1100, 
                            min_square_footage = 590, 
                            max_square_footage = 2100, 
                            average_days_on_market = 25, 
                            median_days_on_market = 8, 
                            min_days_on_market = 1, 
                            max_days_on_market = 304, 
                            new_listings = 18, 
                            total_listings = 76, ), ), )
            )
        else:
            return RentcastMarketStatistics200Response(
        )
        """

    def testRentcastMarketStatistics200Response(self):
        """Test RentcastMarketStatistics200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_value_estimate401_response import RentcastValueEstimate401Response

class TestRentcastValueEstimate401Response(unittest.TestCase):
    """RentcastValueEstimate401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastValueEstimate401Response:
        """Test RentcastValueEstimate401Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastValueEstimate401Response`
        """
        model = RentcastValueEstimate401Response()
        if include_optional:
            return RentcastValueEstimate401Response(
                status = 401,
                error = 'auth/api-key-invalid',
                message = 'No API key provided in request. An API key must be provided in the 'X-Api-Key' header'
            )
        else:
            return RentcastValueEstimate401Response(
        )
        """

    def testRentcastValueEstimate401Response(self):
        """Test RentcastValueEstimate401Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_sale_data import RentcastMarketStatistics200ResponseSaleData

class TestRentcastMarketStatistics200ResponseSaleData(unittest.TestCase):
    """RentcastMarketStatistics200ResponseSaleData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseSaleData:
        """Test RentcastMarketStatistics200ResponseSaleData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseSaleData`
        """
        model = RentcastMarketStatistics200ResponseSaleData()
        if include_optional:
            return RentcastMarketStatistics200ResponseSaleData(
                last_updated_date = '2024-10-14T00:00:00.000Z',
                average_price = 291933,
                median_price = 276990,
                min_price = 20000,
                max_price = 1500000,
                average_price_per_square_foot = 186.53,
                median_price_per_square_foot = 178,
                min_price_per_square_foot = 64.9,
                max_price_per_square_foot = 500,
                average_square_footage = 1698,
                median_square_footage = 1600,
                min_square_footage = 610,
                max_square_footage = 4588,
                average_days_on_market = 67.21,
                median_days_on_market = 45,
                min_days_on_market = 2,
                max_days_on_market = 348,
                new_listings = 21,
                total_listings = 265,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_sale_data_data_by_property_type_inner.market_statistics_200_response_saleData_dataByPropertyType_inner(
                        property_type = 'Condo', 
                        average_price = 144900, 
                        median_price = 144900, 
                        min_price = 144900, 
                        max_price = 144900, 
                        average_price_per_square_foot = 129.26, 
                        median_price_per_square_foot = 129.26, 
                        min_price_per_square_foot = 129.26, 
                        max_price_per_square_foot = 129.26, 
                        average_square_footage = 1121, 
                        median_square_footage = 1121, 
                        min_square_footage = 1121, 
                        max_square_footage = 1121, 
                        average_days_on_market = 61, 
                        median_days_on_market = 61, 
                        min_days_on_market = 61, 
                        max_days_on_market = 61, 
                        new_listings = 0, 
                        total_listings = 1, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_sale_data_data_by_bedrooms_inner.market_statistics_200_response_saleData_dataByBedrooms_inner(
                        bedrooms = 1, 
                        average_price = 186725, 
                        median_price = 153000, 
                        min_price = 147900, 
                        max_price = 237000, 
                        average_price_per_square_foot = 240.84, 
                        median_price_per_square_foot = 191.01, 
                        min_price_per_square_foot = 184.88, 
                        max_price_per_square_foot = 342.62, 
                        average_square_footage = 795, 
                        median_square_footage = 800, 
                        min_square_footage = 610, 
                        max_square_footage = 968, 
                        average_days_on_market = 123, 
                        median_days_on_market = 56, 
                        min_days_on_market = 20, 
                        max_days_on_market = 314, 
                        new_listings = 0, 
                        total_listings = 4, )
                    ],
                history = rentcast_client.models.market_statistics_200_response_sale_data_history.market_statistics_200_response_saleData_history(
                    2024_08 = rentcast_client.models.market_statistics_200_response_sale_data_history_2024_08.market_statistics_200_response_saleData_history_2024_08(
                        date = '2024-08-01T00:00:00.000Z', 
                        average_price = 304256, 
                        median_price = 284900, 
                        min_price = 75000, 
                        max_price = 975000, 
                        average_price_per_square_foot = 177.79, 
                        median_price_per_square_foot = 174.82, 
                        min_price_per_square_foot = 115.81, 
                        max_price_per_square_foot = 342.62, 
                        average_square_footage = 1759, 
                        median_square_footage = 1591, 
                        min_square_footage = 610, 
                        max_square_footage = 4588, 
                        average_days_on_market = 56.94, 
                        median_days_on_market = 41, 
                        min_days_on_market = 2, 
                        max_days_on_market = 327, 
                        new_listings = 56, 
                        total_listings = 215, 
                        data_by_property_type = [
                            rentcast_client.models.market_statistics_200_response_sale_data_history_2024_08_data_by_property_type_inner.market_statistics_200_response_saleData_history_2024_08_dataByPropertyType_inner(
                                property_type = 'Condo', 
                                average_price = 175445, 
                                median_price = 154500, 
                                min_price = 154500, 
                                max_price = 196390, 
                                average_price_per_square_foot = null, 
                                median_price_per_square_foot = null, 
                                min_price_per_square_foot = null, 
                                max_price_per_square_foot = null, 
                                average_square_footage = null, 
                                median_square_footage = null, 
                                min_square_footage = null, 
                                max_square_footage = null, 
                                average_days_on_market = 124, 
                                median_days_on_market = 18, 
                                min_days_on_market = 18, 
                                max_days_on_market = 230, 
                                new_listings = 1, 
                                total_listings = 2, )
                            ], 
                        data_by_bedrooms = [
                            rentcast_client.models.market_statistics_200_response_sale_data_history_2024_08_data_by_bedrooms_inner.market_statistics_200_response_saleData_history_2024_08_dataByBedrooms_inner(
                                bedrooms = 1, 
                                average_price = 197967, 
                                median_price = 209000, 
                                min_price = 147900, 
                                max_price = 237000, 
                                average_price_per_square_foot = 342.62, 
                                median_price_per_square_foot = 342.62, 
                                min_price_per_square_foot = 342.62, 
                                max_price_per_square_foot = 342.62, 
                                average_square_footage = 610, 
                                median_square_footage = 610, 
                                min_square_footage = 610, 
                                max_square_footage = 610, 
                                average_days_on_market = 132, 
                                median_days_on_market = 69, 
                                min_days_on_market = 56, 
                                max_days_on_market = 271, 
                                new_listings = 0, 
                                total_listings = 3, )
                            ], ), 
                    2024_09 = rentcast_client.models.market_statistics_200_response_sale_data_history_2024_09.market_statistics_200_response_saleData_history_2024_09(
                        date = '2024-09-01T00:00:00.000Z', 
                        average_price = 291174, 
                        median_price = 277990, 
                        min_price = 20000, 
                        max_price = 1500000, 
                        average_price_per_square_foot = 187.39, 
                        median_price_per_square_foot = 178, 
                        min_price_per_square_foot = 64.9, 
                        max_price_per_square_foot = 500, 
                        average_square_footage = 1695, 
                        median_square_footage = 1600, 
                        min_square_footage = 610, 
                        max_square_footage = 4588, 
                        average_days_on_market = 63.65, 
                        median_days_on_market = 41, 
                        min_days_on_market = 2, 
                        max_days_on_market = 357, 
                        new_listings = 66, 
                        total_listings = 269, ), 
                    2024_10 = rentcast_client.models.market_statistics_200_response_sale_data_history_2024_10.market_statistics_200_response_saleData_history_2024_10(
                        date = '2024-10-01T00:00:00.000Z', 
                        average_price = 291933, 
                        median_price = 276990, 
                        min_price = 20000, 
                        max_price = 1500000, 
                        average_price_per_square_foot = 186.53, 
                        median_price_per_square_foot = 178, 
                        min_price_per_square_foot = 64.9, 
                        max_price_per_square_foot = 500, 
                        average_square_footage = 1698, 
                        median_square_footage = 1600, 
                        min_square_footage = 610, 
                        max_square_footage = 4588, 
                        average_days_on_market = 67.21, 
                        median_days_on_market = 45, 
                        min_days_on_market = 2, 
                        max_days_on_market = 348, 
                        new_listings = 21, 
                        total_listings = 265, ), )
            )
        else:
            return RentcastMarketStatistics200ResponseSaleData(
        )
        """

    def testRentcastMarketStatistics200ResponseSaleData(self):
        """Test RentcastMarketStatistics200ResponseSaleData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202506_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner

class TestRentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner(
                bedrooms = 1,
                average_rent = 852,
                median_rent = 930,
                min_rent = 400,
                max_rent = 1100,
                average_rent_per_square_foot = 1.35,
                median_rent_per_square_foot = 1.34,
                min_rent_per_square_foot = 1,
                max_rent_per_square_foot = 1.6,
                average_square_footage = 673,
                median_square_footage = 650,
                min_square_footage = 590,
                max_square_footage = 800,
                average_days_on_market = 47.4,
                median_days_on_market = 1,
                min_days_on_market = 1,
                max_days_on_market = 257,
                new_listings = 5,
                total_listings = 11
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202506DataByBedroomsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_rent_estimate_long_term200_response import RentcastRentEstimateLongTerm200Response

class TestRentcastRentEstimateLongTerm200Response(unittest.TestCase):
    """RentcastRentEstimateLongTerm200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastRentEstimateLongTerm200Response:
        """Test RentcastRentEstimateLongTerm200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastRentEstimateLongTerm200Response`
        """
        model = RentcastRentEstimateLongTerm200Response()
        if include_optional:
            return RentcastRentEstimateLongTerm200Response(
                rent = 1670,
                rent_range_low = 1630,
                rent_range_high = 1710,
                latitude = 29.475962,
                longitude = -98.351442,
                comparables = [
                    rentcast_client.models.rent_estimate_long_term_200_response_comparables_inner.rent_estimate_long_term_200_response_comparables_inner(
                        id = '5711-Leon-Pl,-San-Antonio,-TX-78244', 
                        formatted_address = '5711 Leon Pl, San Antonio, TX 78244', 
                        address_line1 = '5711 Leon Pl', 
                        address_line2 = null, 
                        city = 'San Antonio', 
                        state = 'TX', 
                        zip_code = '78244', 
                        county = 'Bexar', 
                        latitude = 29.481808, 
                        longitude = -98.346176, 
                        property_type = 'Single Family', 
                        bedrooms = 4, 
                        bathrooms = 2, 
                        square_footage = 1627, 
                        lot_size = 4617, 
                        year_built = 2021, 
                        price = 1690, 
                        listing_type = 'Standard', 
                        listed_date = '2024-03-15T00:00:00.000Z', 
                        removed_date = '2024-07-04T00:00:00.000Z', 
                        last_seen_date = '2024-07-03T04:26:03.433Z', 
                        days_on_market = 111, 
                        distance = 0.5139, 
                        days_old = 88, 
                        correlation = 0.9879, )
                    ]
            )
        else:
            return RentcastRentEstimateLongTerm200Response(
        )
        """

    def testRentcastRentEstimateLongTerm200Response(self):
        """Test RentcastRentEstimateLongTerm200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from rentcast_client.models.rentcast_sale_listings200_response_inner_history import RentcastSaleListings200ResponseInnerHistory
from rentcast_client.models.rentcast_sale_listings200_response_inner_hoa import RentcastSaleListings200ResponseInnerHoa
from rentcast_client.models.rentcast_sale_listings200_response_inner_listing_agent import RentcastSaleListings200ResponseInnerListingAgent
from rentcast_client.models.rentcast_sale_listings200_response_inner_listing_office import RentcastSaleListings200ResponseInnerListingOffice
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class RentcastSaleListings200ResponseInner(BaseModel):
    """
    RentcastSaleListings200ResponseInner
    """ # noqa: E501
    id: Optional[StrictStr] = None
    formatted_address: Optional[StrictStr] = Field(default=None, alias="formattedAddress")
    address_line1: Optional[StrictStr] = Field(default=None, alias="addressLine1")
    address_line2: Optional[StrictStr] = Field(default=None, alias="addressLine2")
    city: Optional[StrictStr] = None
    state: Optional[StrictStr] = None
    state_fips: Optional[StrictStr] = Field(default=None, alias="stateFips")
    zip_code: Optional[StrictStr] = Field(default=None, alias="zipCode")
    county: Optional[StrictStr] = None
    county_fips: Optional[StrictStr] = Field(default=None, alias="countyFips")
    latitude: Optional[Union[StrictFloat, StrictInt]] = None
    longitude: Optional[Union[StrictFloat, StrictInt]] = None
    property_type: Optional[StrictStr] = Field(default=None, alias="propertyType")
    bedrooms: Optional[Union[StrictFloat, StrictInt]] = None
    bathrooms: Optional[Union[StrictFloat, StrictInt]] = None
    square_footage: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="squareFootage")
    lot_size: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="lotSize")
    year_built: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="yearBuilt")
    hoa: Optional[RentcastSaleListings200ResponseInnerHoa] = None
    status: Optional[StrictStr] = None
    price: Optional[Union[StrictFloat, StrictInt]] = None
    listing_type: Optional[StrictStr] = Field(default=None, alias="listingType")
    listed_date: Optional[datetime] = Field(default=None, alias="listedDate")
    removed_date: Optional[datetime] = Field(default=None, alias="removedDate")
    created_date: Optional[datetime] = Field(default=None, alias="createdDate")
    last_seen_date: Optional[datetime] = Field(default=None, alias="lastSeenDate")
    days_on_market: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="daysOnMarket")
    mls_name: Optional[StrictStr] = Field(default=None, alias="mlsName")
    mls_number: Optional[StrictStr] = Field(default=None, alias="mlsNumber")
    listing_agent: Optional[RentcastSaleListings200ResponseInnerListingAgent] = Field(default=None, alias="listingAgent")
    listing_office: Optional[RentcastSaleListings200ResponseInnerListingOffice] = Field(default=None, alias="listingOffice")
    history: Optional[RentcastSaleListings200ResponseInnerHistory] = None
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["id", "formattedAddress", "addressLine1", "addressLine2", "city", "state", "stateFips", "zipCode", "county", "countyFips", "latitude", "longitude", "propertyType", "bedrooms", "bathrooms", "squareFootage", "lotSize", "yearBuilt", "hoa", "status", "price", "listingType", "listedDate", "removedDate", "createdDate", "lastSeenDate", "daysOnMarket", "mlsName", "mlsNumber", "listingAgent", "listingOffice", "history"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RentcastSaleListings200ResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of hoa
        if self.hoa:
            _dict['hoa'] = self.hoa.to_dict()
        # override the default output from pydantic by calling `to_dict()` of listing_agent
        if self.listing_agent:
            _dict['listingAgent'] = self.listing_agent.to_dict()
        # override the default output from pydantic by calling `to_dict()` of listing_office
        if self.listing_office:
            _dict['listingOffice'] = self.listing_office.to_dict()
        # override the default output from pydantic by calling `to_dict()` of history
        if self.history:
            _dict['history'] = self.history.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RentcastSaleListings200ResponseInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "formattedAddress": obj.get("formattedAddress"),
            "addressLine1": obj.get("addressLine1"),
            "addressLine2": obj.get("addressLine2"),
            "city": obj.get("city"),
            "state": obj.get("state"),
            "stateFips": obj.get("stateFips"),
            "zipCode": obj.get("zipCode"),
            "county": obj.get("county"),
            "countyFips": obj.get("countyFips"),
            "latitude": obj.get("latitude") if obj.get("latitude") is not None else None,
            "longitude": obj.get("longitude") if obj.get("longitude") is not None else None,
            "propertyType": obj.get("propertyType"),
            "bedrooms": obj.get("bedrooms") if obj.get("bedrooms") is not None else None,
            "bathrooms": obj.get("bathrooms") if obj.get("bathrooms") is not None else None,
            "squareFootage": obj.get("squareFootage") if obj.get("squareFootage") is not None else None,
            "lotSize": obj.get("lotSize") if obj.get("lotSize") is not None else None,
            "yearBuilt": obj.get("yearBuilt") if obj.get("yearBuilt") is not None else None,
            "hoa": RentcastSaleListings200ResponseInnerHoa.from_dict(obj["hoa"]) if obj.get("hoa") is not None else None,
            "status": obj.get("status"),
            "price": obj.get("price") if obj.get("price") is not None else None,
            "listingType": obj.get("listingType"),
            "listedDate": obj.get("listedDate"),
            "removedDate": obj.get("removedDate"),
            "createdDate": obj.get("createdDate"),
            "lastSeenDate": obj.get("lastSeenDate"),
            "daysOnMarket": obj.get("daysOnMarket") if obj.get("daysOnMarket") is not None else None,
            "mlsName": obj.get("mlsName"),
            "mlsNumber": obj.get("mlsNumber"),
            "listingAgent": RentcastSaleListings200ResponseInnerListingAgent.from_dict(obj["listingAgent"]) if obj.get("listingAgent") is not None else None,
            "listingOffice": RentcastSaleListings200ResponseInnerListingOffice.from_dict(obj["listingOffice"]) if obj.get("listingOffice") is not None else None,
            "history": RentcastSaleListings200ResponseInnerHistory.from_dict(obj["history"]) if obj.get("history") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_value_estimate200_response_comparables_inner import RentcastValueEstimate200ResponseComparablesInner

class TestRentcastValueEstimate200ResponseComparablesInner(unittest.TestCase):
    """RentcastValueEstimate200ResponseComparablesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastValueEstimate200ResponseComparablesInner:
        """Test RentcastValueEstimate200ResponseComparablesInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastValueEstimate200ResponseComparablesInner`
        """
        model = RentcastValueEstimate200ResponseComparablesInner()
        if include_optional:
            return RentcastValueEstimate200ResponseComparablesInner(
                id = '5014-Fern-Lk,-San-Antonio,-TX-78244',
                formatted_address = '5014 Fern Lk, San Antonio, TX 78244',
                address_line1 = '5014 Fern Lk',
                address_line2 = None,
                city = 'San Antonio',
                state = 'TX',
                zip_code = '78244',
                county = 'Bexar',
                latitude = 29.471777,
                longitude = -98.350172,
                property_type = 'Single Family',
                bedrooms = 4,
                bathrooms = 2,
                square_footage = 1747,
                lot_size = 6316,
                year_built = 1986,
                price = 229900,
                listing_type = 'Standard',
                listed_date = '2024-04-03T00:00:00.000Z',
                removed_date = '2024-05-26T00:00:00.000Z',
                last_seen_date = '2024-05-25T13:11:55.018Z',
                days_on_market = 53,
                distance = 0.2994,
                days_old = 127,
                correlation = 0.9822
            )
        else:
            return RentcastValueEstimate200ResponseComparablesInner(
        )
        """

    def testRentcastValueEstimate200ResponseComparablesInner(self):
        """Test RentcastValueEstimate200ResponseComparablesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202410 import RentcastMarketStatistics200ResponseRentalDataHistory202410

class TestRentcastMarketStatistics200ResponseRentalDataHistory202410(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202410 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202410:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202410
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202410`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202410()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202410(
                var_date = '2024-10-01T00:00:00.000Z',
                average_rent = 1521,
                median_rent = 1495,
                min_rent = 750,
                max_rent = 2700,
                average_rent_per_square_foot = 1.38,
                median_rent_per_square_foot = 1.3,
                min_rent_per_square_foot = 0.86,
                max_rent_per_square_foot = 2.59,
                average_square_footage = 1175,
                median_square_footage = 1100,
                min_square_footage = 590,
                max_square_footage = 2100,
                average_days_on_market = 25,
                median_days_on_market = 8,
                min_days_on_market = 1,
                max_days_on_market = 304,
                new_listings = 18,
                total_listings = 76,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_rental_data_data_by_property_type_inner.market_statistics_200_response_rentalData_dataByPropertyType_inner(
                        property_type = 'Apartment', 
                        average_rent = 1148, 
                        median_rent = 1050, 
                        min_rent = 750, 
                        max_rent = 1975, 
                        average_rent_per_square_foot = 1.23, 
                        median_rent_per_square_foot = 1.13, 
                        min_rent_per_square_foot = 1.03, 
                        max_rent_per_square_foot = 1.59, 
                        average_square_footage = 957, 
                        median_square_footage = 950, 
                        min_square_footage = 650, 
                        max_square_footage = 1560, 
                        average_days_on_market = 17.43, 
                        median_days_on_market = 1, 
                        min_days_on_market = 1, 
                        max_days_on_market = 80, 
                        new_listings = 5, 
                        total_listings = 15, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_rental_data_data_by_bedrooms_inner.market_statistics_200_response_rentalData_dataByBedrooms_inner(
                        bedrooms = 1, 
                        average_rent = 842, 
                        median_rent = 850, 
                        min_rent = 750, 
                        max_rent = 945, 
                        average_rent_per_square_foot = 1.35, 
                        median_rent_per_square_foot = 1.3, 
                        min_rent_per_square_foot = 1.06, 
                        max_rent_per_square_foot = 1.57, 
                        average_square_footage = 679, 
                        median_square_footage = 650, 
                        min_square_footage = 590, 
                        max_square_footage = 800, 
                        average_days_on_market = 27.33, 
                        median_days_on_market = 9, 
                        min_days_on_market = 1, 
                        max_days_on_market = 80, 
                        new_listings = 1, 
                        total_listings = 7, )
                    ]
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202410(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202410(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202410"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner import RentcastRentalListingsLongTerm200ResponseInner

class TestRentcastRentalListingsLongTerm200ResponseInner(unittest.TestCase):
    """RentcastRentalListingsLongTerm200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastRentalListingsLongTerm200ResponseInner:
        """Test RentcastRentalListingsLongTerm200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastRentalListingsLongTerm200ResponseInner`
        """
        model = RentcastRentalListingsLongTerm200ResponseInner()
        if include_optional:
            return RentcastRentalListingsLongTerm200ResponseInner(
                id = '2005-Arborside-Dr,-Austin,-TX-78754',
                formatted_address = '2005 Arborside Dr, Austin, TX 78754',
                address_line1 = '2005 Arborside Dr',
                address_line2 = None,
                city = 'Austin',
                state = 'TX',
                zip_code = '78754',
                county = 'Travis',
                latitude = 30.35837,
                longitude = -97.66508,
                property_type = 'Single Family',
                bedrooms = 3,
                bathrooms = 2.5,
                square_footage = 1681,
                lot_size = 4360,
                year_built = 2019,
                hoa = rentcast_client.models.rental_listings_long_term_200_response_inner_hoa.rental_listings_long_term_200_response_inner_hoa(
                    fee = 45, ),
                status = 'Active',
                price = 2200,
                listing_type = 'Standard',
                listed_date = '2024-09-18T00:00:00.000Z',
                removed_date = None,
                created_date = '2024-09-19T00:00:00.000Z',
                last_seen_date = '2024-09-30T03:49:20.620Z',
                days_on_market = 13,
                mls_name = 'CentralTexas',
                mls_number = '556965',
                listing_agent = rentcast_client.models.rental_listings_long_term_200_response_inner_listing_agent.rental_listings_long_term_200_response_inner_listingAgent(
                    name = 'Zachary Barton', 
                    phone = '5129948203', 
                    email = 'zak-barton@realtytexas.com', 
                    website = 'https://zak-barton.realtytexas.homes', ),
                listing_office = rentcast_client.models.rental_listings_long_term_200_response_inner_listing_office.rental_listings_long_term_200_response_inner_listingOffice(
                    name = 'Realty Texas', 
                    phone = '5124765348', 
                    email = 'sales@realtytexas.com', 
                    website = 'https://www.realtytexas.com', ),
                history = rentcast_client.models.rental_listings_long_term_200_response_inner_history.rental_listings_long_term_200_response_inner_history(
                    2024_09_18 = rentcast_client.models.rental_listings_long_term_200_response_inner_history_2024_09_18.rental_listings_long_term_200_response_inner_history_2024_09_18(
                        event = 'Rental Listing', 
                        price = 2200, 
                        listing_type = 'Standard', 
                        listed_date = '2024-09-18T00:00:00.000Z', 
                        removed_date = null, 
                        days_on_market = 13, ), )
            )
        else:
            return RentcastRentalListingsLongTerm200ResponseInner(
        )
        """

    def testRentcastRentalListingsLongTerm200ResponseInner(self):
        """Test RentcastRentalListingsLongTerm200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_property_records200_response_inner import RentcastPropertyRecords200ResponseInner

class TestRentcastPropertyRecords200ResponseInner(unittest.TestCase):
    """RentcastPropertyRecords200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastPropertyRecords200ResponseInner:
        """Test RentcastPropertyRecords200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastPropertyRecords200ResponseInner`
        """
        model = RentcastPropertyRecords200ResponseInner()
        if include_optional:
            return RentcastPropertyRecords200ResponseInner(
                id = '5500-Grand-Lake-Dr,-San-Antonio,-TX-78244',
                formatted_address = '5500 Grand Lake Dr, San Antonio, TX 78244',
                address_line1 = '5500 Grand Lake Dr',
                address_line2 = None,
                city = 'San Antonio',
                state = 'TX',
                zip_code = '78244',
                county = 'Bexar',
                latitude = 29.476011,
                longitude = -98.351454,
                property_type = 'Single Family',
                bedrooms = 3,
                bathrooms = 2,
                square_footage = 1878,
                lot_size = 8843,
                year_built = 1973,
                assessor_id = '05076-103-0500',
                legal_description = 'CB 5076A BLK 3 LOT 50',
                subdivision = 'CONV A/S CODE',
                zoning = 'RH',
                last_sale_date = '2017-10-19T00:00:00.000Z',
                last_sale_price = 185000,
                hoa = rentcast_client.models.property_records_200_response_inner_hoa.property_records_200_response_inner_hoa(
                    fee = 175, ),
                features = rentcast_client.models.property_records_200_response_inner_features.property_records_200_response_inner_features(
                    architecture_type = 'Contemporary', 
                    cooling = True, 
                    cooling_type = 'Central', 
                    exterior_type = 'Wood', 
                    fireplace = True, 
                    fireplace_type = 'Masonry', 
                    floor_count = 1, 
                    foundation_type = 'Slab / Mat / Raft', 
                    garage = True, 
                    garage_spaces = 2, 
                    garage_type = 'Garage', 
                    heating = True, 
                    heating_type = 'Forced Air', 
                    pool = True, 
                    pool_type = 'Concrete', 
                    roof_type = 'Asphalt', 
                    room_count = 5, 
                    unit_count = 1, 
                    view_type = 'City', ),
                tax_assessments = rentcast_client.models.property_records_200_response_inner_tax_assessments.property_records_200_response_inner_taxAssessments(
                    2019 = rentcast_client.models.property_records_200_response_inner_tax_assessments_2019.property_records_200_response_inner_taxAssessments_2019(
                        year = 2019, 
                        value = 135430, 
                        land = 23450, 
                        improvements = 111980, ), 
                    2020 = rentcast_client.models.property_records_200_response_inner_tax_assessments_2020.property_records_200_response_inner_taxAssessments_2020(
                        year = 2020, 
                        value = 142610, 
                        land = 23450, 
                        improvements = 119160, ), 
                    2021 = rentcast_client.models.property_records_200_response_inner_tax_assessments_2021.property_records_200_response_inner_taxAssessments_2021(
                        year = 2021, 
                        value = 163440, 
                        land = 45050, 
                        improvements = 118390, ), 
                    2022 = rentcast_client.models.property_records_200_response_inner_tax_assessments_2022.property_records_200_response_inner_taxAssessments_2022(
                        year = 2022, 
                        value = 197600, 
                        land = 49560, 
                        improvements = 148040, ), 
                    2023 = rentcast_client.models.property_records_200_response_inner_tax_assessments_2023.property_records_200_response_inner_taxAssessments_2023(
                        year = 2023, 
                        value = 225790, 
                        land = 59380, 
                        improvements = 166410, ), ),
                property_taxes = rentcast_client.models.property_records_200_response_inner_property_taxes.property_records_200_response_inner_propertyTaxes(
                    2019 = rentcast_client.models.property_records_200_response_inner_property_taxes_2019.property_records_200_response_inner_propertyTaxes_2019(
                        year = 2019, 
                        total = 2984, ), 
                    2020 = rentcast_client.models.property_records_200_response_inner_property_taxes_2020.property_records_200_response_inner_propertyTaxes_2020(
                        year = 2020, 
                        total = 3023, ), 
                    2021 = rentcast_client.models.property_records_200_response_inner_property_taxes_2021.property_records_200_response_inner_propertyTaxes_2021(
                        year = 2021, 
                        total = 3455, ), 
                    2022 = rentcast_client.models.property_records_200_response_inner_property_taxes_2022.property_records_200_response_inner_propertyTaxes_2022(
                        year = 2022, 
                        total = 4091, ), 
                    2023 = rentcast_client.models.property_records_200_response_inner_property_taxes_2023.property_records_200_response_inner_propertyTaxes_2023(
                        year = 2023, 
                        total = 4201, ), ),
                history = rentcast_client.models.property_records_200_response_inner_history.property_records_200_response_inner_history(
                    2004_06_16 = rentcast_client.models.property_records_200_response_inner_history_2004_06_16.property_records_200_response_inner_history_2004_06_16(
                        event = 'Sale', 
                        date = '2004-06-16T00:00:00.000Z', 
                        price = 95000, ), 
                    2017_10_19 = rentcast_client.models.property_records_200_response_inner_history_2017_10_19.property_records_200_response_inner_history_2017_10_19(
                        event = 'Sale', 
                        date = '2017-10-19T00:00:00.000Z', 
                        price = 185000, ), ),
                owner = rentcast_client.models.property_records_200_response_inner_owner.property_records_200_response_inner_owner(
                    names = [
                        'Michael Smith'
                        ], 
                    type = 'Individual', 
                    mailing_address = rentcast_client.models.property_records_200_response_inner_owner_mailing_address.property_records_200_response_inner_owner_mailingAddress(
                        id = '149-Weaver-Blvd,---264,-Weaverville,-NC-28787', 
                        formatted_address = '149 Weaver Blvd, # 264, Weaverville, NC 28787', 
                        address_line1 = '149 Weaver Blvd', 
                        address_line2 = '# 264', 
                        city = 'Weaverville', 
                        state = 'NC', 
                        zip_code = '28787', ), ),
                owner_occupied = False
            )
        else:
            return RentcastPropertyRecords200ResponseInner(
        )
        """

    def testRentcastPropertyRecords200ResponseInner(self):
        """Test RentcastPropertyRecords200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.api.default_rentcast import DefaultRentcast


class TestDefaultRentcast(unittest.IsolatedAsyncioTestCase):
    """DefaultRentcast unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = DefaultRentcast()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_market_statistics(self) -> None:
        """Test case for market_statistics

        Market Statistics
        """
        pass

    async def test_property_record_by_id(self) -> None:
        """Test case for property_record_by_id

        Property Record by Id
        """
        pass

    async def test_property_records(self) -> None:
        """Test case for property_records

        Property Records
        """
        pass

    async def test_property_records_random(self) -> None:
        """Test case for property_records_random

        Random Property Records
        """
        pass

    async def test_rent_estimate_long_term(self) -> None:
        """Test case for rent_estimate_long_term

        Rent Estimate
        """
        pass

    async def test_rental_listing_long_term_by_id(self) -> None:
        """Test case for rental_listing_long_term_by_id

        Rental Listing by Id
        """
        pass

    async def test_rental_listings_long_term(self) -> None:
        """Test case for rental_listings_long_term

        Rental Listings
        """
        pass

    async def test_sale_listing_by_id(self) -> None:
        """Test case for sale_listing_by_id

        Sale Listing by Id
        """
        pass

    async def test_sale_listings(self) -> None:
        """Test case for sale_listings

        Sale Listings
        """
        pass

    async def test_value_estimate(self) -> None:
        """Test case for value_estimate

        Value Estimate
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202409_data_by_bedrooms_inner import RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner

class TestRentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner(unittest.TestCase):
    """RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner:
        """Test RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner`
        """
        model = RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner()
        if include_optional:
            return RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner(
                bedrooms = 1,
                average_price = 188475,
                median_price = 160000,
                min_price = 147900,
                max_price = 237000,
                average_price_per_square_foot = 243.02,
                median_price_per_square_foot = 199.75,
                min_price_per_square_foot = 184.88,
                max_price_per_square_foot = 342.62,
                average_square_footage = 795,
                median_square_footage = 800,
                min_square_footage = 610,
                max_square_footage = 968,
                average_days_on_market = 115,
                median_days_on_market = 56,
                min_days_on_market = 6,
                max_days_on_market = 300,
                new_listings = 1,
                total_listings = 4
            )
        else:
            return RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner(
        )
        """

    def testRentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner(self):
        """Test RentcastMarketStatistics200ResponseSaleDataHistory202409DataByBedroomsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202507_data_by_property_type_inner import RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner

class TestRentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner(
                property_type = 'Apartment',
                average_rent = 1098,
                median_rent = 1025,
                min_rent = 875,
                max_rent = 1835,
                average_rent_per_square_foot = 1.25,
                median_rent_per_square_foot = 1.1,
                min_rent_per_square_foot = 1.05,
                max_rent_per_square_foot = 2.03,
                average_square_footage = 911,
                median_square_footage = 950,
                min_square_footage = 629,
                max_square_footage = 1294,
                average_days_on_market = 58.59,
                median_days_on_market = 1,
                min_days_on_market = 1,
                max_days_on_market = 210,
                new_listings = 14,
                total_listings = 24
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202507DataByPropertyTypeInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_rental_listings_long_term200_response_inner_history20240918 import RentcastRentalListingsLongTerm200ResponseInnerHistory20240918

class TestRentcastRentalListingsLongTerm200ResponseInnerHistory20240918(unittest.TestCase):
    """RentcastRentalListingsLongTerm200ResponseInnerHistory20240918 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastRentalListingsLongTerm200ResponseInnerHistory20240918:
        """Test RentcastRentalListingsLongTerm200ResponseInnerHistory20240918
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastRentalListingsLongTerm200ResponseInnerHistory20240918`
        """
        model = RentcastRentalListingsLongTerm200ResponseInnerHistory20240918()
        if include_optional:
            return RentcastRentalListingsLongTerm200ResponseInnerHistory20240918(
                event = 'Rental Listing',
                price = 2200,
                listing_type = 'Standard',
                listed_date = '2024-09-18T00:00:00.000Z',
                removed_date = None,
                days_on_market = 13
            )
        else:
            return RentcastRentalListingsLongTerm200ResponseInnerHistory20240918(
        )
        """

    def testRentcastRentalListingsLongTerm200ResponseInnerHistory20240918(self):
        """Test RentcastRentalListingsLongTerm200ResponseInnerHistory20240918"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_rental_data_history202507 import RentcastMarketStatistics200ResponseRentalDataHistory202507

class TestRentcastMarketStatistics200ResponseRentalDataHistory202507(unittest.TestCase):
    """RentcastMarketStatistics200ResponseRentalDataHistory202507 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseRentalDataHistory202507:
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202507
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseRentalDataHistory202507`
        """
        model = RentcastMarketStatistics200ResponseRentalDataHistory202507()
        if include_optional:
            return RentcastMarketStatistics200ResponseRentalDataHistory202507(
                var_date = '2025-07-01T00:00:00.000Z',
                average_rent = 1417,
                median_rent = 1350,
                min_rent = 400,
                max_rent = 3200,
                average_rent_per_square_foot = 1.32,
                median_rent_per_square_foot = 1.28,
                min_rent_per_square_foot = 0.88,
                max_rent_per_square_foot = 2.04,
                average_square_footage = 1136,
                median_square_footage = 1024,
                min_square_footage = 590,
                max_square_footage = 2672,
                average_days_on_market = 34.06,
                median_days_on_market = 1,
                min_days_on_market = 1,
                max_days_on_market = 321,
                new_listings = 46,
                total_listings = 94,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_rental_data_history_2025_07_data_by_property_type_inner.market_statistics_200_response_rentalData_history_2025_07_dataByPropertyType_inner(
                        property_type = 'Apartment', 
                        average_rent = 1098, 
                        median_rent = 1025, 
                        min_rent = 875, 
                        max_rent = 1835, 
                        average_rent_per_square_foot = 1.25, 
                        median_rent_per_square_foot = 1.1, 
                        min_rent_per_square_foot = 1.05, 
                        max_rent_per_square_foot = 2.03, 
                        average_square_footage = 911, 
                        median_square_footage = 950, 
                        min_square_footage = 629, 
                        max_square_footage = 1294, 
                        average_days_on_market = 58.59, 
                        median_days_on_market = 1, 
                        min_days_on_market = 1, 
                        max_days_on_market = 210, 
                        new_listings = 14, 
                        total_listings = 24, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_rental_data_history_2025_07_data_by_bedrooms_inner.market_statistics_200_response_rentalData_history_2025_07_dataByBedrooms_inner(
                        bedrooms = 1, 
                        average_rent = 926, 
                        median_rent = 945, 
                        min_rent = 400, 
                        max_rent = 1299, 
                        average_rent_per_square_foot = 1.49, 
                        median_rent_per_square_foot = 1.34, 
                        min_rent_per_square_foot = 1, 
                        max_rent_per_square_foot = 2.03, 
                        average_square_footage = 686, 
                        median_square_footage = 650, 
                        min_square_footage = 590, 
                        max_square_footage = 800, 
                        average_days_on_market = 104.77, 
                        median_days_on_market = 107, 
                        min_days_on_market = 1, 
                        max_days_on_market = 321, 
                        new_listings = 1, 
                        total_listings = 15, )
                    ]
            )
        else:
            return RentcastMarketStatistics200ResponseRentalDataHistory202507(
        )
        """

    def testRentcastMarketStatistics200ResponseRentalDataHistory202507(self):
        """Test RentcastMarketStatistics200ResponseRentalDataHistory202507"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_property_records200_response_inner_history import RentcastPropertyRecords200ResponseInnerHistory

class TestRentcastPropertyRecords200ResponseInnerHistory(unittest.TestCase):
    """RentcastPropertyRecords200ResponseInnerHistory unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastPropertyRecords200ResponseInnerHistory:
        """Test RentcastPropertyRecords200ResponseInnerHistory
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastPropertyRecords200ResponseInnerHistory`
        """
        model = RentcastPropertyRecords200ResponseInnerHistory()
        if include_optional:
            return RentcastPropertyRecords200ResponseInnerHistory(
                var_2004_06_16 = rentcast_client.models.property_records_200_response_inner_history_2004_06_16.property_records_200_response_inner_history_2004_06_16(
                    event = 'Sale', 
                    date = '2004-06-16T00:00:00.000Z', 
                    price = 95000, ),
                var_2017_10_19 = rentcast_client.models.property_records_200_response_inner_history_2017_10_19.property_records_200_response_inner_history_2017_10_19(
                    event = 'Sale', 
                    date = '2017-10-19T00:00:00.000Z', 
                    price = 185000, )
            )
        else:
            return RentcastPropertyRecords200ResponseInnerHistory(
        )
        """

    def testRentcastPropertyRecords200ResponseInnerHistory(self):
        """Test RentcastPropertyRecords200ResponseInnerHistory"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    RentCast API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Contact: support@rentcast.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from rentcast_client.models.rentcast_market_statistics200_response_sale_data_history202506 import RentcastMarketStatistics200ResponseSaleDataHistory202506

class TestRentcastMarketStatistics200ResponseSaleDataHistory202506(unittest.TestCase):
    """RentcastMarketStatistics200ResponseSaleDataHistory202506 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RentcastMarketStatistics200ResponseSaleDataHistory202506:
        """Test RentcastMarketStatistics200ResponseSaleDataHistory202506
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RentcastMarketStatistics200ResponseSaleDataHistory202506`
        """
        model = RentcastMarketStatistics200ResponseSaleDataHistory202506()
        if include_optional:
            return RentcastMarketStatistics200ResponseSaleDataHistory202506(
                var_date = '2025-06-01T00:00:00.000Z',
                average_price = 348402,
                median_price = 290000,
                min_price = 8899,
                max_price = 2530000,
                average_price_per_square_foot = 198.98,
                median_price_per_square_foot = 174.94,
                min_price_per_square_foot = 54,
                max_price_per_square_foot = 962.5,
                average_square_footage = 1712,
                median_square_footage = 1587,
                min_square_footage = 792,
                max_square_footage = 6000,
                average_days_on_market = 76.89,
                median_days_on_market = 54,
                min_days_on_market = 2,
                max_days_on_market = 348,
                new_listings = 47,
                total_listings = 263,
                data_by_property_type = [
                    rentcast_client.models.market_statistics_200_response_sale_data_history_2025_06_data_by_property_type_inner.market_statistics_200_response_saleData_history_2025_06_dataByPropertyType_inner(
                        property_type = 'Condo', 
                        average_price = 380983, 
                        median_price = 125000, 
                        min_price = 105000, 
                        max_price = 1599000, 
                        average_price_per_square_foot = 166.94, 
                        median_price_per_square_foot = 129.63, 
                        min_price_per_square_foot = 119.07, 
                        max_price_per_square_foot = 357.48, 
                        average_square_footage = 1630, 
                        median_square_footage = 1049, 
                        min_square_footage = 810, 
                        max_square_footage = 4473, 
                        average_days_on_market = 92.83, 
                        median_days_on_market = 54, 
                        min_days_on_market = 53, 
                        max_days_on_market = 220, 
                        new_listings = 0, 
                        total_listings = 6, )
                    ],
                data_by_bedrooms = [
                    rentcast_client.models.market_statistics_200_response_sale_data_history_2025_06_data_by_bedrooms_inner.market_statistics_200_response_saleData_history_2025_06_dataByBedrooms_inner(
                        bedrooms = 0, 
                        average_price = 499900, 
                        median_price = 499900, 
                        min_price = 499900, 
                        max_price = 499900, 
                        average_price_per_square_foot = 83.32, 
                        median_price_per_square_foot = 83.32, 
                        min_price_per_square_foot = 83.32, 
                        max_price_per_square_foot = 83.32, 
                        average_square_footage = 6000, 
                        median_square_footage = 6000, 
                        min_square_footage = 6000, 
                        max_square_footage = 6000, 
                        average_days_on_market = 24, 
                        median_days_on_market = 24, 
                        min_days_on_market = 24, 
                        max_days_on_market = 24, 
                        new_listings = 1, 
                        total_listings = 1, )
                    ]
            )
        else:
            return RentcastMarketStatistics200ResponseSaleDataHistory202506(
        )
        """

    def testRentcastMarketStatistics200ResponseSaleDataHistory202506(self):
        """Test RentcastMarketStatistics200ResponseSaleDataHistory202506"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
